@@ -1,7 +1,21 @@
 import re
 from collections import OrderedDict
 
-__all__ = ["ChoiceItem", "ChoicesBase", "C"]
+__all__ = ["ChoiceItem", "DjangoChoices", "C"]
+
+### Support Functionality (Not part of public API ###
+
+class Labels(dict):
+    def __getattribute__(self, name):
+        result = dict.get(self, name, None)
+        if result:
+            return result
+        else:
+            raise AttributeError("Label for field %s was not found." % name)
+    def __setattr__(self, name, value):
+        self[name] = value
+
+### End Support Functionality ###
 
 class ChoiceItem(object):
     """
@@ -25,8 +39,6 @@ C = ChoiceItem
 class DjangoChoicesMeta(type):
     """
     Metaclass that writes the choices class.
-    
-    *NOTE*: Does not support inheritance currently.
     """
     name_clean = re.compile(r"_+")
     def __new__(cls, name, bases, attrs):
@@ -35,8 +47,11 @@ class DjangoChoicesMeta(type):
                 self.value = value
             def __get__(self, obj, objtype):
                 return self.value
-            
+                
         fields = {}
+        labels = Labels()
+        values = {}
+        choices = []
         
         # Get all the fields from parent classes. 
         parents = [b for b in bases if isinstance(b, DjangoChoicesMeta)]
@@ -51,8 +66,7 @@ class DjangoChoicesMeta(type):
                 fields[field_name] = val 
                 
         fields = OrderedDict(sorted(fields.items(), key=lambda x: x[1].order))
-
-        choices = []
+        
         for name in fields:
             val = fields[name]
             if isinstance(val, ChoiceItem):
@@ -62,10 +76,14 @@ class DjangoChoicesMeta(type):
                     label = cls.name_clean.sub(" ", name)
                 choices.append((val.value, label))
                 attrs[name] = StaticProp(val.value)
+                setattr(labels, name, label)
+                values[val.value] = label 
             else:
                 choices.append((name, val.choices))
 
         attrs["choices"] = StaticProp(tuple(choices))
+        attrs["labels"] = labels
+        attrs["values"] = values
         attrs["_fields"] = fields
 
         return super(DjangoChoicesMeta, cls).__new__(cls, name, bases, attrs)
@@ -73,5 +91,6 @@ class DjangoChoicesMeta(type):
 class DjangoChoices(object):
     order = 0
     choices = ()
+    labels = Labels()
+    values = {}
     __metaclass__ = DjangoChoicesMeta
-
